@@ -519,22 +519,6 @@ class KeyboardMouseControler(StackControler, widget.Widget):
             from py2play.idler import IDLER
             IDLER.end_game()
             
-          elif event[1] == soyasdlconst.K_t: a = ACTION_TURBO
-          elif event[1] == soyasdlconst.K_d:
-            character.player.controler.append(Debug(character))
-            return
-          
-          elif event[1] == soyasdlconst.K_e:
-            character.teleport(-25.5768661499, -4.67472076416, -112.708984375)
-            character.look_at(Vector(character.level, 1.0, 0.0, 0.0))
-            from slune.videosequence import LookAtFrontOfCharacterTraveling
-            character.get_root().camera.add_traveling(LookAtFrontOfCharacterTraveling(character))
-            def Cont():
-              while 1:
-                yield Action()
-            character.player.controler.append(Cont())
-            return
-          
           elif event[1] == soyasdlconst.K_s:
             import tempfile
             screenshot_file = tempfile.mktemp(".jpeg")
