@@ -90,10 +90,10 @@ def MainScreen():
       self.left = int((soya.get_screen_width() - self.width) * 0.5)
       if self.valid == 0:
         # HACK
-        self.height = 0
+        self.height = self.font.wordwrap(self.title, self.width)[1] + self.font.wordwrap(self.text, self.width)[1]
         soyaopengl.glColor4f(0.0, 0.0, 0.0, 0.0)
-        self.height += self.font.draw_area(self.title, self.left, 0, self.width, soya.get_screen_height(), 1)
-        self.height += self.font.draw_area(self.text, self.left, 0, self.width, soya.get_screen_height(), 0)
+        self.font.draw_area(self.title, self.left, 0.0, 0.0, self.width, soya.get_screen_height(), 1)
+        self.font.draw_area(self.text , self.left, 0.0, 0.0, self.width, soya.get_screen_height(), 0)
         self.top = int((soya.get_screen_height() - self.height) * 0.5)
         self.valid = 1
       soyaopengl.glEnable(soyaopengl.GL_BLEND)
@@ -106,11 +106,15 @@ def MainScreen():
       soyaopengl.glEnd()
       draw_window(self.width, self.height, self.bg_color)
       soyaopengl.glDisable(soyaopengl.GL_BLEND)
-      self.height = 0
+
       soyaopengl.glColor4f(*self.highlight)
-      self.height += self.font.draw_area(self.title, self.left, self.top, self.width, soya.get_screen_height(), 1)
+      self.font.draw_area(self.title, self.left, self.top, 0.0, self.width, soya.get_screen_height(), 1)
+      self.height = self.font.wordwrap(self.title, self.width)[0]
+      
       soyaopengl.glColor4f(*self.color)
-      self.height += self.font.draw_area(self.text, self.left, self.top + self.height, self.width, soya.get_screen_height(), 0)
+      self.font.draw_area(self.text, self.left, self.top + self.height, 0.0, self.width, soya.get_screen_height(), 0)
+      self.height += self.font.wordwrap(self.text, self.width)[0]
+      
       self.top = int((soya.get_screen_height() - self.height) * 0.5)
       
   class Rectangle(soya.widget.Widget):
