@@ -78,6 +78,7 @@ class BlackBands(widget.Widget):
 class Idler(soya.World, idler.Idler):
   #def __del__(self):
   #  print "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!! del Idler"
+  will_render = 1
   
   def __init__(self, camera = None):
     soya .World.__init__(self)
@@ -264,7 +265,7 @@ class Idler(soya.World, idler.Idler):
     current = time.time()
     if self.messages and (self.messages[0][1] <= current):
       del self.messages[0]
-      self.messageboard.text = "\n".join(map(lambda (text, duration): text, self.messages))
+      self.messageboard.text = "\n".join([text for (text, duration) in self.messages])
       
     # In THIS order !!! Really ends the round before saying to Py2Play it is ended !
     # The camera must be played AFTER the character, for a better visual effect (ie to avoid the character to move after the camera has been moved)
@@ -284,12 +285,12 @@ class Idler(soya.World, idler.Idler):
     
     if len(self.messages) > 3: del self.messages[0]
     
-    self.messageboard.text = "\n".join(map(lambda (text, duration): text, self.messages))
+    self.messageboard.text = "\n".join([text for (text, duration) in self.messages])
     
   def message_append(self, text, duration = 7):
     self.messages[-1] = (self.messages[-1][0] + text, duration + time.time())
     
-    self.messageboard.text = "\n".join(map(lambda (text, duration): text, self.messages))
+    self.messageboard.text = "\n".join([text for (text, duration) in self.messages])
     
 class WaitUntilReady:
   def __init__(self, idler):
@@ -376,7 +377,7 @@ class Level(level.Level, soya.World):
     
   def init_character(self, character):
     if isinstance(character, slune.character.Competitor) and character.controler:
-      character.rank = len(filter(lambda character: isinstance(character, slune.character.Competitor), self.characters)) - 1
+      character.rank = len([character for character in self.characters if isinstance(character, slune.character.Competitor)]) - 1
       
       exec self.init_character_script in globals(), locals()
       
@@ -413,10 +414,10 @@ class Level(level.Level, soya.World):
   def start_game(self):
     exec self.start_script in globals(), locals()
     
-    self.pushables = filter(lambda x: isinstance(x, slune.character.Pusher), self)
-    self.bonuss    = filter(lambda x: isinstance(x, Bonus                 ), self)
-
-    for pushable in filter(lambda x: isinstance(x, slune.character.Pushable), self):
+    self.pushables = [x for x in self if isinstance(x, slune.character.Pusher)]
+    self.bonuss    = [x for x in self if isinstance(x, Bonus                 )]
+    
+    for pushable in [x for x in self if isinstance(x, slune.character.Pushable)]:
       h = self.random.random()
       if   h < pushable.bonus_chance:
         pushable.bonus_type = 1
@@ -438,6 +439,7 @@ class Level(level.Level, soya.World):
       
     
 def CREATE(level_name):
+  if isinstance(level_name, unicode): level_name = level_name.encode("latin")
   lev = pickle.load(open(os.path.join(soya.path[0], soya.World.DIRNAME, level_name + ".data"), "rb"))
   lev.name = level_name
   level.store(lev)
